package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.BERSequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERTaggedObject;
import java.util.Enumeration;

public class EnvelopedData extends ASN1Encodable {
   private DERInteger version;
   private OriginatorInfo originatorInfo;
   private ASN1Set recipientInfos;
   private EncryptedContentInfo encryptedContentInfo;
   private ASN1Set unprotectedAttrs;

   public EnvelopedData(OriginatorInfo originatorInfo, ASN1Set recipientInfos, EncryptedContentInfo encryptedContentInfo, ASN1Set unprotectedAttrs) {
      DERInteger var5;
      if (originatorInfo == null && unprotectedAttrs == null) {
         var5 = new DERInteger.<init>(0);
         this.version = var5;
         Enumeration var6 = recipientInfos.getObjects();

         while(var6.hasMoreElements()) {
            if (!RecipientInfo.getInstance(var6.nextElement()).getVersion().equals(this.version)) {
               var5 = new DERInteger.<init>(2);
               this.version = var5;
               break;
            }
         }
      } else {
         var5 = new DERInteger.<init>(2);
         this.version = var5;
      }

      this.originatorInfo = originatorInfo;
      this.recipientInfos = recipientInfos;
      this.encryptedContentInfo = encryptedContentInfo;
      this.unprotectedAttrs = unprotectedAttrs;
   }

   public EnvelopedData(ASN1Sequence seq) {
      this.version = (DERInteger)seq.getObjectAt(0);
      int var2 = 2;
      DEREncodable var3;
      if ((var3 = seq.getObjectAt(1)) instanceof ASN1TaggedObject) {
         int var10001 = var2;
         this.originatorInfo = OriginatorInfo.getInstance((ASN1TaggedObject)var3, false);
         var2 = 3;
         var3 = seq.getObjectAt(var10001);
      }

      int var10003 = var2;
      this.recipientInfos = ASN1Set.getInstance(var3);
      ++var2;
      this.encryptedContentInfo = EncryptedContentInfo.getInstance(seq.getObjectAt(var10003));
      if (seq.size() > var2) {
         this.unprotectedAttrs = ASN1Set.getInstance((ASN1TaggedObject)seq.getObjectAt(var2), false);
      }

   }

   public static EnvelopedData getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static EnvelopedData getInstance(Object obj) {
      if (obj != null && !(obj instanceof EnvelopedData)) {
         if (obj instanceof ASN1Sequence) {
            return new EnvelopedData((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid EnvelopedData: " + obj.getClass().getName());
         }
      } else {
         return (EnvelopedData)obj;
      }
   }

   public DERInteger getVersion() {
      return this.version;
   }

   public OriginatorInfo getOriginatorInfo() {
      return this.originatorInfo;
   }

   public ASN1Set getRecipientInfos() {
      return this.recipientInfos;
   }

   public EncryptedContentInfo getEncryptedContentInfo() {
      return this.encryptedContentInfo;
   }

   public ASN1Set getUnprotectedAttrs() {
      return this.unprotectedAttrs;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.version);
      OriginatorInfo var2;
      if ((var2 = this.originatorInfo) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(false, 0, var2);
         var1.add(var3);
      }

      var1.add(this.recipientInfos);
      var1.add(this.encryptedContentInfo);
      ASN1Set var4;
      if ((var4 = this.unprotectedAttrs) != null) {
         DERTaggedObject var5;
         var5 = new DERTaggedObject.<init>(false, 1, var4);
         var1.add(var5);
      }

      return new BERSequence(var1);
   }
}
